@@ -13,9 +13,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -359,7 +359,11 @@ int open_zoek_venster (char *titel,char *tekst)
 void str_toupper (char *c)
 {
    int i=0;
-   do {c[i]=toupper(c[i]);++i;} while (c[i]!=0);
+   if ((c!=NULL) && (*c!=0)) {
+
+   	do {c[i]=toupper(c[i]);++i;} while (c[i]!=0);
+
+   }
 }
 
 /* --------------------------------------------	*/
@@ -1428,7 +1432,7 @@ bv.txt_f_open1=txt_f_open1;
 bv.txt_f_load=txt_f_laden;
 bv.txt_f_fseek=txt_f_fseek;
 if (!(initscr())) {
-   fprintf(stderr,txt_f_initscr);exit(1);
+   fprintf(stderr,"%s",txt_f_initscr);exit(1);
    }
 
 set_memerr(outofmemory);
