@@ -13,9 +13,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -29,10 +29,11 @@
 char *only_global(char *line,char **current_section,int *global)
 {
 char *c,*s=line,*globals,*found,*end_section;
-globals=(char *)xmalloc(strlen(line)+1);
+size_t size=strlen(line)+1;
+globals=(char *)xmalloc(size);
 end_section=(char *)xmalloc(1);
 strcpy(globals,line);
-memset(globals,'\0',sizeof(globals));
+memset(globals,'\0',size);
 while(1) {
    if (*global) {
       if((found=strstr(s,"<"))==NULL) {
