@@ -1,20 +1,24 @@
-/* getline.c -- Replacement for GNU C library function getline
-
-Copyright (C) 1993, 1996, 2001, 2002 Free Software Foundation, Inc.
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of the
-License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+/*
+ * getline.c -- Replacement for GNU C library function getline
+ *
+ * Copyright (C) 1993, 1996, 2001, 2002 Free Software Foundation, Inc.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ * 
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ */
 
 /* Written by Jan Brittenson, bson@gnu.ai.mit.edu.  */
 
@@ -30,6 +34,14 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 #ifndef _GNU_SOURCE
 # define _GNU_SOURCE	1
 #endif
+
+#if defined(__FreeBSD__)
+#include <osreldate.h>
+#if __FreeBSD_version >= 900000
+#define _WITH_GETLINE
+#endif
+#endif
+
 #include <stdio.h>
 #include <sys/types.h>
 
@@ -52,12 +64,14 @@ getline (lineptr, n, stream)
 
 #if defined(__FreeBSD__)
 #include <osreldate.h>
+#if __FreeBSD_version < 900000
 #if __FreeBSD_version <= 800066
 int getdelim (lineptr, n, delimiter, stream);
 #else
 ssize_t getdelim (lineptr, n, delimiter, stream);
 #endif
 #endif
+#endif
 
 # include <assert.h>
 
